/*
TASK: F
LANG: C
*/
#include<stdio.h>
#include<stdlib.h>

#define MAXN 1024
#define MAXM 4096
#define EPS 1e-8
#define INF 2000000000

typedef struct edge { int r,next; double c; } edge;
typedef struct line { int l,r; double c; } line;
typedef struct seg { double l,r; } seg;

int h[MAXN],pos[MAXN],beg[MAXN],n,m;
double d[MAXN],f[MAXN][MAXN];
edge e[MAXM<<1];
line a[MAXM];
seg s[MAXN];

int cmp(double e1,double e2)
{
	if(e1-e2<-EPS) return -1;
	if(e1-e2>EPS) return 1;
	return 0;
}

int cmp_s(const void *e1,const void *e2)
{
	return cmp(((seg*)e1)->l-((seg*)e2)->l,0);
}

void shift_down(int i)
{
	int x=h[i],j=i<<1;
	while(j<=h[0])
	{
		if(j+1<=h[0]&&d[h[j+1]]<d[h[j]]) j++;
		if(d[h[j]]>=d[x]) break;
		h[i]=h[j];
		pos[h[i]]=i;
		i=j;
		j<<=1;
	}
	h[i]=x;
	pos[h[i]]=i;
}

void shift_up(int i)
{
	int x=h[i],j=i>>1;
	while(j>=1)
	{
		if(d[h[j]]<=d[x]) break;
		h[i]=h[j];
		pos[h[i]]=i;
		i=j;
		j>>=1;
	}
	h[i]=x;
	pos[h[i]]=i;
}

void push(int x)
{
	h[++h[0]]=x;
	pos[h[h[0]]]=h[0];
	shift_up(h[0]);
}

int pop()
{
	int res=h[1];
	pos[h[1]]=-1;
	h[1]=h[h[0]--];
	pos[h[1]]=1;
	shift_down(1);
	return res;
}

void dijkstra(int x)
{
	int i,v,w;
	for(i=1;i<=n;i++) { d[i]=INF; pos[i]=0; }
	d[x]=0;
	push(x);
	while(h[0]>=1)
	{
		v=pop();
		for(i=beg[v];i!=0;i=e[i].next)
		{
			w=e[i].r;
			if(cmp(d[v]+e[i].c,d[w])<0)
			{
				d[w]=d[v]+e[i].c;
				if(pos[w]) shift_up(pos[w]);
				else push(w);
			}
		}
	}
	for(i=1;i<=n;i++) f[x][i]=d[i];
}

int check(double k)
{
	int i,j,v,w;
	double l,r,tl,tr,c;
	for(i=1;i<=n;i++)
	{
		for(j=1;j<=n;j++) if(cmp(f[j][i],k)>0) break;
		if(j==n+1) return 1;
	}
	for(j=0;j<m;j++)
	{
		v=a[j].l; w=a[j].r; c=a[j].c;
		l=c+1; r=-1;
		for(i=1;i<=n;i++)
		{
			tl=k-f[i][v];
			tr=c-k+f[i][w];
			s[i].l=tl;
			s[i].r=tr;
			if(tl<tr)
			{
				if(tl<l) l=tl;
				if(tr>r) r=tr;
			}
		}
		if(cmp(l,0)>0) return 1;
		if(cmp(r,c)<0) return 1;
		qsort(s+1,n,sizeof(s[0]),cmp_s);
		r=0;
		for(i=1;i<=n;i++)
		{
			if(r<c&&s[i].l>0&&cmp(s[i].l,r)>=0) return 1;
			if(s[i].r>r) r=s[i].r;
		}
	}
	return 0;
}

int main()
{
	int i,l,r,mem=1;
	double c,li,ri,mid,sum=0;
	scanf("%d%d",&n,&m);
	for(i=0;i<m;i++)
	{
		scanf("%d%d%lf",&l,&r,&c);
		e[mem].r=r; e[mem].c=c; e[mem].next=beg[l]; beg[l]=mem++;
		e[mem].r=l; e[mem].c=c; e[mem].next=beg[r]; beg[r]=mem++;
		a[i].l=l; a[i].r=r; a[i].c=c;
		sum+=c;
	}
	for(i=1;i<=n;i++) dijkstra(i);
	li=0; ri=sum; mid=(li+ri)/2;
	for(i=0;i<40;i++)
	{
		mid=(li+ri)/2;
		if(check(mid)) ri=mid;
		else li=mid;
	}
	printf("%.4lf\n",(li+ri)/2);
	return 0;
}
