#include<iostream>

using namespace std;

#define BASE 10000
#define BASE_DIG 4
#define MAXSIZE 30000

class BigInt
{  public: int Size, SizeMax;
           short *Coef;
             
           BigInt();
           BigInt(int);
           BigInt(const BigInt&);
           
           virtual ~BigInt();
           
           BigInt& operator=(const BigInt&);
};
  
BigInt::BigInt()
{  SizeMax = Size = 0;
   Coef = NULL;
}

BigInt::BigInt(int MaxLen)
{  Coef = new short[MaxLen];
   SizeMax = MaxLen;
   Size = 0;
}

BigInt::BigInt(const BigInt &A)
{  SizeMax = A.SizeMax;
   Size = A.Size;
   Coef = new short[SizeMax];
   for(int i=0; i<SizeMax; i++)
     Coef[i] = A.Coef[i];
}

BigInt::~BigInt()
{  delete Coef;
}

inline BigInt& BigInt::operator=(const BigInt &A)
{  const short *a = A.Coef;
   if (this == &A) return *this;
   if (SizeMax < A.Size)
     {  if (Coef) delete Coef;
        Coef = new short[A.Size];
        SizeMax = Size = A.Size;
     }
   else  Size = A.Size;
   
   for(int i=0; i<Size; i++)
     Coef[i] = a[i];
     
   return *this;
}

void Add(const BigInt &A, const BigInt &B, BigInt &C)
{  int i;
   long temp; 
   const short *a=A.Coef, *b=B.Coef;
   short *c=C.Coef, carry = 0;
   if (A.Size < B.Size)
     { Add(B,A,C);
       return;
     }
   for(i=0; i<B.Size; i++)
     {  temp = a[i] + b[i] + carry;
        if (temp >= BASE)
          { c[i] = temp - BASE;
            carry = 1;
          }
        else
          { c[i] = temp;
            carry = 0;
          }
     }
   for(; i < A.Size; i++)
     {  temp = a[i] + carry;
        if (temp >= BASE)
          {  c[i] = temp - BASE;
             carry = 1;
          }
        else
          {  c[i] = temp;
             carry = 0;
          }
     }
               
   if (carry)
     { c[i] = carry;
       C.Size = A.Size + 1;
     }
   else C.Size = A.Size;
}

void Mul(const BigInt &A, const BigInt &B, BigInt &C)
{  int i, j;
   const short *a=A.Coef, *b=B.Coef;
   short *c=C.Coef;
   int temp, carry;
   
   for(i=0; i <= A.Size + B.Size; i++) c[i] = 0;
   
   for(i=0; i < A.Size; i++)
     {  carry = 0;
        for(j=0; j < B.Size; j++)
          { temp = a[i] * b[j] + c[i+j] + carry;
            carry = temp/BASE;
            c[i+j] = temp - carry*BASE;
          }
        c[i+j] = carry;
     }
   
   i = A.Size + B.Size - 1;
   if (c[i] == 0) i--;
   C.Size = i + 1;
}  
          
ostream& operator<<(ostream& os, const BigInt A)
{  
   long j;
   short Pow, Dec, Coef;
   os << A.Coef[A.Size-1];
   
   for (long i=A.Size-2; i>=0; i--)
     {  Pow = BASE/10;
        Coef = A.Coef[i];
        for(j=0; j<BASE_DIG; j++)
          { Dec = Coef/Pow;
            Coef -= Dec*Pow;
            Pow /= 10;
            os << Dec;
          }
     }
   return os;  
}    
             
int main()
{   
    int n;
    cin >> n;
    BigInt A(MAXSIZE), B(MAXSIZE), C(MAXSIZE);
    BigInt E(1); 
    E.Size = 1; E.Coef[0] = 1;
    A = E;
    C = E;
    for(int i = 2; i <= n; i++)
      { Add(A,E,B);
        Mul(A,B,C); 
        A = C;
      }
    cout << A << endl;
    return 0;
}
