/*
TASK: square
LANG: C++
*/
#include <iostream>
#include <queue>
#include <algorithm>
#include <math.h>
using namespace std;

struct point
{
       long long x, y;
       point(long long _x, long long _y):x(_x), y(_y){}
       point(){}
       point operator-(point p)
       {
             return point(x - p.x, y - p.y);
       }
};

long long cross(point p1, point p2)
{
    return p1.x*p2.y - p1.y*p2.x;
}

bool inside(point *a, point p)
{
     int zeros = 0;
     int f = 0;
     for (int i = 0; i < 4; i++)
     {
         int nexti = (i+1)%4;
         long long C = cross(a[nexti] - a[i], p - a[i]);
         if (C == 0) zeros++;
         else if (C > 0) f++;
         else f--;
     }
     return abs(f) + zeros == 4;
}

bool intersect(point p1, point p2, point p3, point p4)
{
     if (max(p1.x, p2.x) < min(p3.x, p4.x)) return 0;
     if (min(p1.x, p2.x) > max(p3.x, p4.x)) return 0;
     if (max(p1.y, p2.y) < min(p3.y, p4.y)) return 0;
     if (min(p1.y, p2.y) > max(p3.y, p4.y)) return 0;
     
     return cross(p2 - p1, p3 - p1)*
            cross(p2 - p1, p4 - p1) <= 0;
}

struct square
{
       int x1, y1, x2, y2;
       square(int _x1, int _y1, int _x2, int _y2)
        :x1(_x1), y1(_y1), x2(_x2), y2(_y2){}
       square(){}
       
       int xm() { return (x1 + x2)/2; }
       int ym() { return (y1 + y2)/2; }
       int x3() { return xm() - (y2 - ym()); }
       int y3() { return ym() + (x2 - xm()); }
       int x4() { return xm() + (y2 - ym()); }
       int y4() { return ym() - (x2 - xm()); }
       
       bool cover(square S)
       {
            point b[4];
            b[0] = point(S.x1, S.y1);
            b[1] = point(S.x3(), S.y3());
            b[2] = point(S.x2, S.y2);
            b[3] = point(S.x4(), S.y4());
            
            point a[4];
            a[0] = point(x1, y1);
            a[1] = point(x3(), y3());
            a[2] = point(x2, y2);
            a[3] = point(x4(), y4());
            
            for (int i = 0; i < 4; i++) 
             if (inside(b, a[i]) || inside(a, b[i]))
              return 1;
            
            for (int i = 0; i < 4; i++)
             for (int j = 0; j < 4; j++)
             {
                 int nexti = (i+1)%4;
                 int nextj = (j+1)%4;
                 
                 if (intersect(a[i], a[nexti], b[j], b[nextj]) &&
                     intersect(b[j], b[nextj], a[i], a[nexti])) return 1;
             }
            return 0;
       }
} P[1000];

struct vertex
{
       int u, next;
       vertex(int _u, int _next):u(_u), next(_next){}
       vertex(){}
} nodes[1000000];
int cnt;
int table[1000];

void add(int a, int b)
{
     nodes[cnt] = vertex(b, table[a]);
     table[a] = cnt++;
}

int main()
{
    memset(table, -1, sizeof(table));
    
    int N;
    cin >> N;
    for (int i = 0; i < N; i++)
    {
        int x1, x2, y1, y2;
        int xm, ym, x, y;
        cin >> xm >> ym >> x >> y;
        
        x1 = min(x, xm + (xm - x)), x2 = max(x, xm + (xm - x));
        y1 = min(y, ym + (ym - y)), y2 = max(y, ym + (ym - y));
        
        P[i] = square(x1, y1, x2, y2);
    }
    
    for (int i = 0; i < N; i++)
     for (int j = i + 1; j < N; j++)
      if (P[i].cover(P[j])) add(i, j), add(j, i);
    
    queue<pair<int, int> > q;
    q.push(make_pair(0, 0));
    bool used[1000];
    memset(used, 0, sizeof(used));
    while (!q.empty())
    {
          int u = (q.front()).first;
          int lvl = (q.front()).second;
          
          q.pop();
          if (u == N-1) { cout << lvl << endl; return 0; }
          
          for (int v = table[u]; v != -1; v = nodes[v].next)
          {
              if (used[nodes[v].u]) continue;
              
              used[ nodes[v].u ] = 1;
              q.push(make_pair(nodes[v].u, lvl + 1));
          }
    }
    cout << -1 << endl;
    return 0;
}
