/*
TASK: square
LANG: C++
*/

#include <cstdio>
using namespace std;

const int MAX_N = 1024;

struct point {
       int x, y;
       point () {}
       point (int _x, int _y) : x(_x), y(_y) {}
       point operator+ (point a) { return point(x+a.x,y+a.y); }
       point operator- (point a) { return point(x-a.x,y-a.y); }
       point rot () { return point(-y,x); }
};
struct square { point o, a[4]; };

int n;
square A[MAX_N];
bool M[MAX_N][MAX_N];
int V[MAX_N];

void input ()
{
     int i, j;
     
     scanf ("%d", &n);

     for (i=0; i<n; i++) {
         scanf ("%d%d%d%d", &A[i].o.x, &A[i].o.y, &A[i].a[0].x, &A[i].a[0].y);
         
         for (j=1; j<4; j++)
             A[i].a[j] = A[i].o + (A[i].a[j-1]-A[i].o).rot();
         
         //printf ("%d: o=(%d,%d) a=(%d,%d) b=(%d,%d) c=(%d,%d) d=(%d,%d)\n", i, A[i].o.x, A[i].o.y, A[i].a[0].x, A[i].a[0].y, A[i].a[1].x, A[i].a[1].y, A[i].a[2].x, A[i].a[2].y, A[i].a[3].x, A[i].a[3].y);
     }
}

int orient (point &a, point &b, point &c)
{
    return (b.x-a.x)*(c.y-b.y) - (c.x-b.x)*(b.y-a.y);
}

inline int sign (int a) { return a<0?-1:a>0?+1:0; }

bool intersect (point &a, point &b, point &c, point &d)
{
     if ( sign(orient(a,b,c)) * sign(orient(a,b,d)) >= 0 ) return 0;
     if ( sign(orient(c,d,a)) * sign(orient(c,d,b)) >= 0 ) return 0;
     
     return 1;
}

bool inside (point &p, square &a)
{
     int i;
     bool s[3]={0,0,0};
     
     for (i=0; i<4; i++)
         s[ sign(orient(p,a.a[i],a.a[(i+1)%4]))+1 ] |= 1;
         
     //printf ("%d %d %d\n", s[0], s[1], s[2]);
     if (s[1]) return 0;
     return s[0]^s[2];
}

bool intersect (square &a, square &b)
{
     int i, j;
     
     for (i=0; i<4; i++) if ( inside(a.a[i],b) ) return 1;
     for (i=0; i<4; i++) if ( inside(b.a[i],a) ) return 1;

     for (i=0; i<4; i++){
         if ( intersect(a.a[0],a.a[2],b.a[i],b.a[(i+1)%4]) ) return 1;
         if ( intersect(a.a[1],a.a[3],b.a[i],b.a[(i+1)%4]) ) return 1;
     }
     
     for (i=0; i<4; i++){
         if ( intersect(b.a[0],b.a[2],a.a[i],a.a[(i+1)%4]) ) return 1;
         if ( intersect(b.a[1],b.a[3],a.a[i],a.a[(i+1)%4]) ) return 1;
     }
     
     for (i=0; i<4; i++)
         for (j=0; j<4; j++)
             if ( intersect(a.a[i], a.a[(i+1)%4], b.a[j], b.a[(j+1)%4]) ) return 1;
                
     return 0;
}

void construct_graph ()
{
     int i, j;
     
     for (i=0; i<n; i++)
         for (j=i+1; j<n; j++)
             if ( intersect(A[i],A[j]) ) {
                M[i][j] = M[j][i] = 1;
               // printf ("%d<->%d\n", i, j);
             }
}

void bfs ()
{
     int Q[MAX_N], f=0, l=0, p, i;
     
     Q[l++] = 0;
     V[0]=1;
     while (f<l) {
           p = Q[f++];
           for (i=0; i<n; i++)
               if (!V[i] && M[p][i]) {
                  Q[l++] = i;
                  V[i] = V[p]+1;
               }
     }
}

int main ()
{
    //freopen ("square.in", "r", stdin);
    
    input ();
    construct_graph ();
    bfs ();
    
    printf ("%d\n", V[n-1]-1);
    
    return 0;
}
