#include<iostream>
#include<queue>
#include<stack>
using namespace std;

struct move
{
	short x;
	short y;
	short orientation;
	int door_state;	

	move & operator=(move & other);
	move(short _x, short _y, short _orientation, int _door_state);
	move();
	
	void try_to_make_move();
	void make_move(int, int, int, int);
	bool is_final_position();
	void work_key_at(int, int);
	bool weak_tile_check();
	bool open_door_check(int, int);
	void get_move_coordinates(int);
	void find_path();
	static void input();
};


namespace variables
{
	#define MAXX 25
	#define MAXY 25
	#define DOORS 1024
	#define ORIENTATIONS 3
	
	enum {UP,RIGHT,STAND};
	enum {Up,Down,Right,Left};
	
	int x1,y1,x2,y2,new_door_state,direction;
	int mask[11],mask_open[44],mask_close[44],mask_toggle[44];
	int table[MAXX][MAXY];
	bool used[MAXX][MAXY][ORIENTATIONS][DOORS];
	short lastdirection[MAXX][MAXY][ORIENTATIONS][DOORS];
	move lastmove[MAXX][MAXY][ORIENTATIONS][DOORS];
	
	queue<move> q;
	int endx,endy;
	
	//What moves can be made from any one orientation?
	short possiblemoves[3][4][2][2]=
	{
		{	{{-1,0},{-1,0}} , {{2,0},{2,0}}, {{0,1},{1,1}}, {{0,-1},{1,-1}}	}, //laying vertically
		{	{{-1,0},{-1,1}}, {{1,0},{1,1}}, {{0,2},{0,2}}, {{0,-1},{0,-1}}	}, //laying horizontally
		{	{{-2,0},{-1,0}} , {{1,0},{2,0}}, {{0,1},{0,2}}, {{0,-2},{0,-1}}	}  //standing upright
		/* move up			move down 		move right		move left */
	};
	
	//To which orientation can we switch with move X? (possible orientations)
	short posorient[3][4]=
	{
		{STAND,STAND,UP,UP},
		{RIGHT,RIGHT,STAND,STAND},
		{UP,UP,RIGHT,RIGHT}
	};
}

using namespace variables;



int main(){
	
	move currentmove;
	move::input();
	
	while(!q.empty()){
		currentmove=q.front();
		q.pop();

		if(currentmove.is_final_position())
		{
			currentmove.find_path();
			return 0;
		}
		else currentmove.try_to_make_move();
	}

	printf("0\nImpossible\n");
return 0;
}



inline void move::work_key_at(int x,int y)
{
	if(table[x][y]>=20&&table[x][y]<40)
	{
		new_door_state|=mask_open[table[x][y]-20];
		new_door_state&=mask_close[table[x][y]-20];
		new_door_state^=mask_toggle[table[x][y]-20];
	}
}

inline bool move::weak_tile_check()
{
	return !(x1==x2&&y1==y2&&table[x1][y1]==2);
}


inline void move::get_move_coordinates(int direction)
{
	x1=x+possiblemoves[orientation][direction][0][0];
	y1=y+possiblemoves[orientation][direction][0][1];
	x2=x+possiblemoves[orientation][direction][1][0];
	y2=y+possiblemoves[orientation][direction][1][1];
}

/*
a,b and c are the new x,y,and orientation coordinates,
d is the direction of the last move.
*/
inline void move::make_move(int a,int b,int c,int d)
{
	move tmp(a,b,c,new_door_state);
	q.push(tmp);
	used[a][b][c][new_door_state]=true;
	lastdirection[a][b][c][new_door_state]=d;
	move tmp2(x,y,orientation,door_state);
	lastmove[a][b][c][new_door_state]=tmp2;
}

inline bool move::open_door_check(int x,int y)
{
	return (!(table[x][y]>=10&&table[x][y]<20)
			||
			(door_state&mask[table[x][y]-10]));
}

void move::try_to_make_move()
{
	/* Try to make all four moves from the current position */
	/* 0 - Up, 1 - Down, 2 - Right, 3 - Left */
	for(direction=0;direction<4;++direction)
	{
		get_move_coordinates(direction);
		/* Change doors that need to be changed. */
		new_door_state=door_state;
		work_key_at(x1,y1);
		if(!(x1==x2&&y1==y2))
			work_key_at(x2,y2);

		/* Check if a move is legal */
		/* Has this position been reached before? */
		if(!used[x1][y1][ posorient[orientation][direction] ][new_door_state])
		{
			/* Is there solid ground under the block? */
			if(table[x2][y2] && table[x1][y1])
				if(open_door_check(x1,y1) && open_door_check(x2,y2) && weak_tile_check())
					make_move(x1, y1, posorient[orientation][direction], direction);		
		}
	}
return;
}

/* Finds a path from the last position to the initial one; */
inline void move::find_path()
{
	stack<int> s;
	char answer[4][1]={{'u'},{'d'},{'r'},{'l'}};
	int count=0;
	while(lastdirection[x][y][orientation][door_state]!=-1)
	{
		s.push(lastdirection[x][y][orientation][door_state]);
		*this=lastmove[x][y][orientation][door_state];
	}
	
	printf("%d\n",s.size());
	while(!s.empty()){
		count++;
		printf("%c",answer[s.top()][0]);
		s.pop();
	}
	printf("\n");
return;
}

inline bool move::is_final_position()
{
	return (x==endx&&y==endy&&orientation==STAND);
}

move::move()
{
	x=0;
	y=0;
	orientation=0;
	door_state=0;
}

move & move::operator=(move & other)
{
	x=other.x;
	y=other.y;
	orientation=other.orientation;
	door_state=other.door_state;
	return *this;
}
	
move::move(short _x=0,short _y=0,short _orientation=0,int _door_state=0)
{
	x=_x;
	y=_y;
	orientation=_orientation;
	door_state=_door_state;
}

inline void move::input()
{
	int m,n;
	int startx,starty;
	int k=0,p=0,door_state,x,y;
	char t,a,b,c;
		scanf("%d%d",&n,&m);
	
	/* Read the table */
	for(x=2;x<=n+1;x++){
		scanf("%c",&t);
		for(y=2;y<=m+1;y++){
			scanf("%c",&t);
			if(t==' ')	table[x][y]=0;
			else if(t=='.')	table[x][y]=1;
			else if(t=='^')	table[x][y]=2;
			else if(t=='K')	table[x][y]=20+(k++);		
			else if(t>='0'&&t<='9')	{table[x][y]=t-'0'+10;p++;}
			else if(t=='S')	{startx=x;starty=y;table[x][y]=1;}
			else if(t=='E')	{endx=x;endy=y;table[x][y]=1;}
		}
	}
	scanf("%c",&c);

	mask[0]=1;
	for(x=1;x<10;x++)
		mask[x]=mask[x-1]*2;

	/* Read keys and set up masks */
	for(x=0;x<k;x++){
		c='0';
		while(c!='\n'){
			scanf("%c%c%c",&a,&b,&c);
			if(a=='O')mask_open[x]+=mask[b-'0'];
			if(a=='C')mask_close[x]-=mask[b-'0'];
			if(a=='T')mask_toggle[x]+=mask[b-'0'];
			}
	}
	
	door_state=mask[p]-1;
	for(x=0;x<40;x++)mask_close[x]+=door_state;
	
	/* Read doors */
	door_state=0;
	for(x=0;x<p;x++){
		scanf("%c",&a);
		door_state+=(a-'0')*mask[x];
	}

	/* Set up the initial state */
	move firstmove(startx,starty,STAND,door_state);
	q.push(firstmove);
	used[startx][starty][STAND][door_state]=1;
	lastdirection[startx][starty][STAND][door_state]=-1;

return;
}
