/*
TASK:alaska
LANG:C++
*/

#include <cstdio>
#include <vector>
#include <iostream>
using namespace std;

const double eps=1e-5;

struct point { double x, y; };

vector<point> A;   // non-convex
vector<point> B;   // convex

double ans=0.0;

void input ()
{
	point p;
	char s[1000];
	
	while (cin.getline(s,1000,'\n'), s[0]!='\0') {
		sscanf (s, "%lf%lf", &p.x, &p.y);
		A.push_back (p);
	}

	while (cin.getline(s,1000,'\n')){
		sscanf (s, "%lf%lf", &p.x, &p.y);
		B.push_back (p);
	}
}

inline double orient (point &a, point &b, point &c)
{
	return (b.x-a.x)*(c.y-b.y) - (c.x-b.x)*(b.y-a.y);
}

void normalize (vector<point> &V)
{
	int i, p;
	
	for (p=0, i=1; i<V.size(); i++)
		if (V[i].y<V[p].y || (V[i].y==V[p].y && V[i].x<V[p].x))
			p=i;
	
	if ( orient( V[(p-1+V.size())%V.size()], V[p], V[(p+1)%V.size()] ) < 0 )
		reverse (V.begin(), V.end());	
}

void calc_area (vector<point> &t)
{
	int i;
	
	for (i=1; i<t.size()-1; i++)
		ans += orient(t[0],t[i],t[(i+1)%t.size()]);
}

point intersect_line_line (point &a, point &b, point &c, point &d)
{
	double coef = orient(a,c,b) / orient(c,b,d);
	
	point p;
	p.x = a.x + (b.x-a.x)*coef;
	p.y = a.y + (b.y-a.y)*coef;
	
	//printf ("coef: %lf", coef);
	//printf ("intersect_line_line_intersect: (%.1lf,%.1lf)(%.1lf,%.1lf) (%.1lf,%.1lf)(%.1lf,%.1lf)  p=(%.1lf,%.1lf)  \n", a.x, a.y, b.x, b.y, c.x, c.y, d.x, d.y, p.x, p.y);
	
	return p;
}

void print (vector<point> &t)
{
	int i;
	
	for (i=0; i<t.size(); i++)
		printf ("(%.1lf,%.1lf) ", t[i].x, t[i].y);
	printf ("\n");
}

void intersect_poly_halfplane (vector<point> &t, point &a, point &b)
{
	int i;
	double p, q;
	
	printf ("a=(%.1lf,%.1lf) b=(%.1lf,%.1lf)\n", a.x, a.y, b.x, b.y);
	printf ("intersect_poly_halfplane begin: (%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t[0].x, t[0].y, t[1].x, t[1].y, t[2].x, t[2].y);
	
	for (i=0; i<t.size(); i++) {
		p = orient(a,b,t[i]);
		q = orient(a,b,t[(i+1)%t.size()]);
		
		printf ("p=%.1lf q=%.1lf\n", p, q);
		
		if (p<0-eps) {
			//printf ("tuk1");
			if (q<0-eps) t.erase(t.begin()+i);
			else t[i] = intersect_line_line (t[i],t[i+1],a,b);
			i--;
		} else { //p>0
			//printf ("tuk2");
			if (q<0-eps) {
				//printf ("t[%d]=(%.1lf,%.1lf)\n", i, a.x, a.y);
				//printf ("t[%d]=(%.1lf,%.1lf)\n", i, b.x, b.y);
				t[i+1] = intersect_line_line (t[i],t[i+1],a,b);
				//printf ("t[%d]=(%.1lf,%.1lf)\n", i+1, t[i+1].x, t[i+1].y);
				i--;
			}
		}
		print (t);
	}

	printf ("intersect_poly_halfplane end: (%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t[0].x, t[0].y, t[1].x, t[1].y, t[2].x, t[2].y);
}

void intersect_tri_tri (vector<point> &t1, vector<point> &t2)
{
	//printf ("!\n");
	//printf ("intersect_tri_tri: (%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t2[0].x, t2[0].y, t2[1].x, t2[1].y, t2[2].x, t2[2].y);
	intersect_poly_halfplane (t1,t2[0],t2[1]);
	intersect_poly_halfplane (t1,t2[1],t2[2]);
	intersect_poly_halfplane (t1,t2[2],t2[0]);
	
	calc_area (t1);
}

void intersect_B_tri (vector<point> &t1)
{
	int i;
		
	for (i=1; i<B.size()-1; i++) {
		//printf ("intersect_B_tri begin: (%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t1[0].x, t1[0].y, t1[1].x, t1[1].y, t1[2].x, t1[2].y);
		
		vector<point> t2;
		t2.push_back (B[0]);
		t2.push_back (B[i]);
		t2.push_back (B[i+1]);
		
		intersect_tri_tri (t1,t2);
		//printf ("intersect_B_tri end: (%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t1[0].x, t1[0].y, t1[1].x, t1[1].y, t1[2].x, t1[2].y);
	}
}

void solve ()
{
	int i, j;
	int n=A.size();
	
	normalize (A);
	normalize (B);
	
	for (i=0; i<n-2; i++) //for each triangle in A
		for (j=0; j<A.size(); j++) {
			vector<point> t;
			t.push_back (A[(j-1+A.size())%A.size()]);
			t.push_back (A[j]);
			t.push_back (A[(j+1)%A.size()]);
			
			//printf ("(%.1lf,%.1lf)(%.1lf,%.1lf)(%.1lf,%.1lf)   \n", t[0].x, t[0].y, t[1].x, t[1].y, t[2].x, t[2].y);
			
			if ( orient(t[0],t[1],t[2]) >= 0 ) {
				intersect_B_tri (t);
				A.erase (A.begin()+j);
				break;
			}
		}
}

int main ()
{
	printf ("0\n");
	return 0;
	
	input ();
	solve ();
	
	printf ("%.2lf\n", ans/2.0);
	
	return 0;
}
