/*
 * Author: Andrei Homescu
 * O(N^3logK + N^3), Gauss for determinant, 100 points
 */
#include <iostream>
#include <sstream>
#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <cstdarg>
#include <cstring>
#include <cctype>
#include <cmath>
#include <algorithm>
#include <numeric>
#include <utility>
#include <string>
#include <vector>
#include <list>
#include <deque>
#include <queue>
#include <stack>
#include <set>
#include <map>

using namespace std;

#define	REP( i, n )         for( (i) = 0 ; (i) < (n) ; (i)++ )
#define	IREP( i, n )	    for( (i) = (n) - 1 ; (i) >= 0 ; (i)-- )
#define REPV( i, a, b )     for( (i) = (a) ; (i) <= (b) ; (i)++ )
#define IREPV( i, a, b )    for( (i) = (b) ; (i) >= (a) ; (i)-- )
#define REPIT( it, x )      for( (it) = (x).begin( ) ; (it) != (x).end( ) ; (it)++ )
#define ALL( x )            (x).begin( ), (x).end( )
#define MP                  make_pair
#define PB                  push_back
#define CLR( x )            memset( (x), 0, sizeof( x ) )
#define CLRV( x, v )        memset( (x), (v), sizeof( x ) )
#define CPY( y, x )         memcpy( (y), (x), sizeof( x ) )
#define	X                   first
#define Y                   second

typedef long long Ll;
typedef pair< int, int > Pii;
typedef pair< Ll, Ll > Pll;
typedef vector< int > Vi;
typedef vector< Ll > Vl;
typedef vector< string > Vs;

const int MAXN = 50, MODULO = 9901, INF = 0x3f3f3f3f;
const Ll INFL = 0x3f3f3f3f3f3f3f3fLL;
const double EPS = 1e-9;
int n, k;
int multInv[MODULO];

class Matrix
{
public:
    Matrix( int n ): n_( n )
    {
        data_ = new int[n * n];
        memset( data_, 0, n * n * sizeof( *data_ ) );
    }

    Matrix( const Matrix &mx )
    {
        n_ = mx.n_;
        data_ = new int[n_ * n_];
        memcpy( data_, mx.data_, n_ * n_ * sizeof( *data_ ) );
    }

    Matrix &operator=( const Matrix &mx )
    {
        if( &mx == this )
            return *this;

        delete [] data_;
        n_ = mx.n_;
        data_ = new int[n_ * n_];
        memcpy( data_, mx.data_, n_ * n_ * sizeof( *data_ ) );
        return *this;
    }

    ~Matrix( )
    {
        delete [] data_;
    }

    int *operator[]( int idx )
    {
        return data_ + idx * n_;
    }

    const int *operator[]( int idx ) const
    {
        return data_ + idx * n_;
    }

    Matrix operator+( const Matrix &mx )
    {
        assert( n_ == mx.n_ );
        Matrix res( n_ );
        int i;
        for( i = 0 ; i < n_ * n_ ; i++ )
            res.data_[i] = (data_[i] + mx.data_[i]) % MODULO;
        return res;
    }

    Matrix &operator+=( const Matrix &mx )
    {
        assert( n_ == mx.n_ );
        int i;
        for( i = 0 ; i < n_ * n_ ; i++ )
            data_[i] = (data_[i] + mx.data_[i]) % MODULO;
        return *this;
    }

    Matrix operator*( const Matrix &mx )
    {
        assert( n_ == mx.n_ );
        Matrix res( n_ );
        int i, j, k;
        for( i = 0 ; i < n_ ; i++ )
            for( k = 0 ; k < n_ ; k++ )
                for( j = 0 ; j < n_ ; j++ )
                {
                    res[i][j] += (*this)[i][k] * mx[k][j];
                    res[i][j] %= MODULO;
                }
        return res;
    }

    int determinant( );

    int size( ) const
    {
        return n_;
    }

    static Matrix eye( int n )
    {
        Matrix res( n );
        int i;
        for( i = 0 ; i < n ; i++ )
            res[i][i] = 1;
        return res;
    }

private:
    Matrix( ) { };

    int n_;
    int *data_;
};

int Matrix::determinant( )
{
    int res = 1, i, j, k, invaii, cf;
    Matrix tmp( *this );
    for( i = 0 ; i < n_ ; i++ )
    {
        res = (res * tmp[i][i]) % MODULO;
        invaii = ((MODULO - 1) * multInv[tmp[i][i]]) % MODULO;
        for( j = i + 1 ; j < n_ ; j++ )
            for( k = i + 1 ; k < n_ ; k++ )
            {
                cf = (tmp[j][i] * tmp[i][k]) % MODULO;
                tmp[j][k] += cf * invaii;
                tmp[j][k] %= MODULO;
            }
    }
    return res;
}

pair< Matrix, Matrix > sumOfMatrixPowers( const Matrix &a, int pow )
{
    int n = a.size( );
    if( pow == 0 )
        return MP( Matrix::eye( n ), Matrix( n ) );
    if( pow == 1 )
        return MP( a, Matrix::eye( n ) );

    if( pow & 1 )
    {
        pair< Matrix, Matrix > oneLessRes(
            sumOfMatrixPowers( a, pow - 1 ) );
        return MP( oneLessRes.X * a,
                   oneLessRes.Y + oneLessRes.X );
    }
    else
    {
        pair< Matrix, Matrix > halfRes(
            sumOfMatrixPowers( a, pow >> 1 ) );
        return MP( halfRes.X * halfRes.X,
                   halfRes.Y + halfRes.X * halfRes.Y );
    }
}

int main( )
{
    freopen( "det.in", "r", stdin );
    freopen( "det.out", "w", stdout );

    int i, j;
    scanf( "%d%d", &n, &k );

    multInv[1] = 1;
    for( i = 2 ; i < MODULO ; i++ )
        if( multInv[i] == 0 )
            for( j = 2 ; j < MODULO ; j++ )
                if( (i * j) % MODULO == 1 )
                {
                    multInv[i] = j;
                    multInv[j] = i;
                }

    Matrix a( n );
    for( i = 0 ; i < n ; i++ )
        for( j = 0 ; j < n ; j++ )
            scanf( "%d", &a[i][j] );

    pair< Matrix, Matrix > powRes( sumOfMatrixPowers( a, k + 1 ) );  
    printf( "%d\n", powRes.Y.determinant( ) );
    return 0;    
}

